@@ -33,12 +33,18 @@ class HangmanTestCase(unittest.TestCase):
         self.assertGreaterEqual(ifs_within_while, 1, 'You should have at least one if statement inside the while loop to check that the entered input is a single letter')
     
     def test_check_letter(self):
-        self.assertIn('if guess in word', self.code, 'You should use an if statement to check if the letter entered by the user is in the word. Remember that the input should be stored in a variable called "guess" and the randomly picked word should be stored in a variable called "word". You can use the "in" operator to check if a character is in a string. If you think you have done it correctly, remember to use the right indentation for the if statement and just a single space between the "if" keyword and the condition')
+        acceptable_inputs = ['if guess.lower() in word', 'if guess in word.lower()', 'if guess.lower() in word.lower()', 'if guess in word']
+        check_if = False
+        for acceptable_input in acceptable_inputs:
+            if acceptable_input in self.code:
+                check_if = True
+                break
+        self.assertTrue(check_if, 'You should use an if statement to check if the letter entered by the user is in the word. Remember that the input should be stored in a variable called "guess" and the randomly picked word should be stored in a variable called "word". You can use the "in" operator to check if a character is in a string. If you think you have done it correctly, remember to use the right indentation for the if statement and just a single space between the "if" keyword and the condition')
         # Check the line number of the if statement and the else statement
         if_found = False
         n_line_else = 0
         for n, line in enumerate(self.lines):
-            if 'if guess in word' in line:
+            if any(acceptable_input in line for acceptable_input in acceptable_inputs):
                 n_line_if = n
                 if_found = True
             if 'else' in line and if_found:
