@@ -72,7 +72,7 @@ class HangmanTestCase(unittest.TestCase):
                     except:
                         self.fail(' : Something went wrong when running the play_game function. Make sure you have defined the function correctly in the milestone_5.py file. The "game" variable should be an instance of the Hangman class, and you have to pass two arguments in the right order. Additionally, make sure you do not have any infinite loops in your code, so remember to add "break" statements in the right places')
                     message = f.getvalue()
-            self.assertIn('Congratulation. You won the game!', message, 'The play_game function should print "Congratulation. You won the game!" when the user wins the game. If you are not sure what is wrong, try to run the play_game function with the word "banana" and the following inputs: "b", "a", "n"')
+            self.assertIn('Congratulations. You won the game!', message, 'The play_game function should print "Congratulations. You won the game!" when the user wins the game. If you are not sure what is wrong, try to run the play_game function with the word "banana" and the following inputs: "b", "a", "n"')
             f = io.StringIO()
             with redirect_stdout(f):
                 with patch('builtins.input', side_effect=['z', 'w', 'c', 'd', 'e', 'f']):
